@@ -4,6 +4,7 @@ import socketio
 import ubjson
 from multiprocessing.dummy import Pool
 import msgpack
+import requests
 
 class GSCNodeFunctionReceiverSocket:
     @classmethod
@@ -77,7 +78,7 @@ class GSCNodeFunctionCallerSocket:
 
         @self.sio.event
         def connect():
-            self._logger.info('oncnodefunction connected')
+            self._logger.warning('oncnodefunction connected')
 
         @self.sio.event
         def cnodeanswer(id, message):
@@ -128,3 +129,40 @@ class GSCNodeFunctionCaller:
                                args=[self.sio, target, msg],
                                callback=self.on_success,
                                error_callback=self.on_errorPost)
+class GSCNodeFunctionCallerRest:
+    def __init__(self, gsdbs, oncnodefunctionanswer):
+
+        self.gsdbs = gsdbs
+        self.oncnodefunctionanswer = oncnodefunctionanswer
+        self._pool = Pool(self.gsdbs.credentials["poolsize"])
+        self._logger = logging.getLogger(__name__)
+
+    def on_success(self, r):
+        self._logger.debug('cnodefunction succeed')
+
+    def on_errorPost(self, error):
+        self._logger.exception('cnodefunction failed :' + str(error))
+
+    def emitFunction(self, target, msg, timeout):
+        msg["cnodefunction"] = target
+
+        encoded = ubjson.dumpb(msg)
+        try:
+            r = requests.post(target, data=encoded, timeout=timeout)
+            self.oncnodefunctionanswer(self.gsdbs, ubjson.loadb(r.content))
+        except requests.exceptions.Timeout:
+            self._logger.exception("timeout")
+            self.oncnodefunctionanswer(self.gsdbs, {"error": "true",
+                                                    "message": "capacity reached"})
+        except requests.exceptions.RequestException as e:
+            self._logger.exception("something went very wrong" + str(e))
+            self.oncnodefunctionanswer(self.gsdbs, {"error": "true",
+                                                    "message": "capacity reached"})
+
+        # sio.emit("oncnodefunction", {"target": target, "data": encoded})
+
+    def sendcnodefunction(self, target, msg, timeout):
+        self._pool.apply_async(self.emitFunction,
+                               args=[target, msg, timeout],
+                               callback=self.on_success,
+                               error_callback=self.on_errorPost)
\ No newline at end of file
