@@ -305,7 +305,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
             bitrate=int(target_bitrate),
             # quality=self.gsdbs.credentials["quality"]
         )
-
+        camera.annotate_text = datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")
         broadcast_thread.start()
         self.peerConnections = {}
 
@@ -323,10 +323,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         @self.sio.event
         async def broadcaster(id, description,emitter):
 
-            if emitter == "watcher":
-                return
-
-
             if len(self.rtconfiList) > 0:
                 pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
             else:
