@@ -154,7 +154,7 @@ class GSPeerConnectionWatcherNew:
 
     @classmethod
     async def create(cls, connectionWatcher, gsdbs, target, onframe=None, onmessage=None, ontrack=None,
-                     ontrackended=None,  signalingserver=None):
+                     ontrackended=None, signalingserver=None):
         self = connectionWatcher
         self.rtconfiList = []
         self.sio = socketio.AsyncClient()
@@ -181,9 +181,9 @@ class GSPeerConnectionWatcherNew:
             self.logger.info('connection established')
 
         @self.sio.event
-        async def bjoined(id):
+        async def bjoined(id, type):
             self.logger.info("broadcaster received")
-            # await self.sio.emit("broadcaster", {"id": id, "target": self.target,"emitter":"js"})
+            await self.sio.emit("broadcaster", {"id": id, "target": self.target, "emitter": "python"})
 
         @self.sio.event
         async def joined(id):
@@ -231,35 +231,36 @@ class GSPeerConnectionWatcherNew:
 
         @self.sio.event
         async def watcher(id, description):
-            if len(self.rtconfiList) > 0:
-                self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
-            else:
-                self.peerConnections = RTCPeerConnection()
-            if type(description) == str:
-                description = ast.literal_eval(description)
+            if self.peerConnections is None:
+                if len(self.rtconfiList) > 0:
+                    self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
+                else:
+                    self.peerConnections = RTCPeerConnection()
+                if type(description) == str:
+                    description = ast.literal_eval(description)
 
-            offer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
+                offer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
-            self.peerConnections.addTransceiver('video', direction='recvonly')
+                self.peerConnections.addTransceiver('video', direction='recvonly')
 
-            @self.peerConnections.on("track")
-            async def on_track(track):
-                if track.kind == "video":
-                    if self.ontrack is not None:
-                        self.logger.info("on track received.Recording started")
-                        await self.ontrack(self.gsdbs, track, self.target)
-                    if self.onframe is not None:
-                        self.logger.info("on track received. onframe started")
-                        self.gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
-                        self.gsmediaconsumer.addTrack(track)
-                        await self.gsmediaconsumer.start()
+                @self.peerConnections.on("track")
+                async def on_track(track):
+                    if track.kind == "video":
+                        if self.ontrack is not None:
+                            self.logger.info("on track received.Recording started")
+                            await self.ontrack(self.gsdbs, track, self.target)
+                        if self.onframe is not None:
+                            self.logger.info("on track received. onframe started")
+                            self.gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
+                            self.gsmediaconsumer.addTrack(track)
+                            await self.gsmediaconsumer.start()
 
-            await self.peerConnections.setRemoteDescription(offer)
-            await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
-            await self.sio.emit("answer",
-                                {"id": id,
-                                 "message": {"type": self.peerConnections.localDescription.type,
-                                             "sdp": self.peerConnections.localDescription.sdp}})
+                await self.peerConnections.setRemoteDescription(offer)
+                await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
+                await self.sio.emit("answer",
+                                    {"id": id,
+                                     "message": {"type": self.peerConnections.localDescription.type,
+                                                 "sdp": self.peerConnections.localDescription.sdp}})
 
         @self.sio.event
         async def answer(id, description):
